
.. _docs:

API Documentation
=================

Here you can find a list of Wonderwords modules and their relevant
documentations. If you are new to Wonderwords, it is highly suggested that you
start with :ref:`the quickstart <quickstart>`.

.. toctree::
  :maxdepth: 2

  api
  cli
